pub struct RcuGuard<'a, T> { /* private fields */ }Expand description
A guard that provides read access to a value in an RcuCell.
When this guard is dropped, it will signal that the read operation
is complete, allowing the RcuCell to manage its internal state
accordingly.